@@ -3,15 +3,16 @@ import os
 import signal
 import sys
 import warnings
-from openai.validators import (
-    write_out_file,
-    apply_necessary_remediation,
-    apply_optional_remediation,
-    read_any_format,
-    get_validators,
-)
 
 import openai
+from openai.upload_progress import BufferReader
+from openai.validators import (
+    apply_necessary_remediation,
+    apply_optional_remediation,
+    get_validators,
+    read_any_format,
+    write_out_file,
+)
 
 
 class bcolors:
@@ -60,9 +61,7 @@ class Engine:
 
     @classmethod
     def update(cls, args):
-        engine = openai.Engine(id=args.id)
-        engine.replicas = args.replicas
-        engine.save()
+        engine = openai.Engine.modify(args.id, replicas=args.replicas)
         display(engine)
 
     @classmethod
@@ -102,7 +101,6 @@ class Engine:
 
     @classmethod
     def search(cls, args):
-        # Will soon be deprecated and replaced by a Search.create
         params = {
             "query": args.query,
             "max_rerank": args.max_rerank,
@@ -113,6 +111,9 @@ class Engine:
         if args.file:
             params["file"] = args.file
 
+        if args.version:
+            params["version"] = args.version
+
         resp = openai.Engine(id=args.id).search(**params)
         scores = [
             (search_result["score"], search_result["document"])
@@ -179,14 +180,12 @@ class Completion:
 class Model:
     @classmethod
     def get(cls, args):
-        resp = openai.Model.retrieve(
-            id=args.id,
-        )
+        resp = openai.Model.retrieve(id=args.id)
         print(resp)
 
     @classmethod
     def delete(cls, args):
-        model = openai.Model(id=args.id).delete()
+        model = openai.Model.delete(args.id)
         print(model)
 
     @classmethod
@@ -198,10 +197,10 @@ class Model:
 class File:
     @classmethod
     def create(cls, args):
+        with open(args.file, "rb") as file_reader:
+            buffer_reader = BufferReader(file_reader.read(), desc="Upload progress")
         resp = openai.File.create(
-            file=open(args.file),
-            purpose=args.purpose,
-            model=args.model,
+            file=buffer_reader, purpose=args.purpose, model=args.model
         )
         print(resp)
 
@@ -212,7 +211,7 @@ class File:
 
     @classmethod
     def delete(cls, args):
-        file = openai.File(id=args.id).delete()
+        file = openai.File.delete(args.id)
         print(file)
 
     @classmethod
@@ -221,6 +220,17 @@ class File:
         print(file)
 
 
+class Search:
+    @classmethod
+    def create_alpha(cls, args):
+        resp = openai.Search.create_alpha(
+            query=[args.query],
+            max_documents=args.max_documents,
+            file_id=args.file,
+        )
+        print(resp)
+
+
 class FineTune:
     @classmethod
     def list(cls, args):
@@ -589,6 +599,11 @@ Mutually exclusive with `top_p`.""",
         type=bool,
         default=False,
     )
+    sub.add_argument(
+        "--version",
+        help="The version of the search routing to use",
+    )
+
     sub.add_argument("-q", "--query", required=True, help="Search query")
     sub.set_defaults(func=Engine.search)
 
@@ -688,6 +703,30 @@ Mutually exclusive with `top_p`.""",
     sub = subparsers.add_parser("files.list")
     sub.set_defaults(func=File.list)
 
+    # Search
+    sub = subparsers.add_parser("search.create_alpha")
+
+    sub.add_argument(
+        "-f",
+        "--file",
+        required=True,
+        help="ID for previously uploaded file that contains the documents you want to search",
+    )
+    sub.add_argument(
+        "-m",
+        "--max_documents",
+        help="The maximum number of documents to return",
+        type=int,
+        default=200,
+    )
+    sub.add_argument(
+        "-q",
+        "--query",
+        required=True,
+        help="Search query",
+    )
+    sub.set_defaults(func=Search.create_alpha)
+
     # Finetune
     sub = subparsers.add_parser("fine_tunes.list")
     sub.set_defaults(func=FineTune.list)
